@@ -1,4 +1,5 @@
-# Copyright 2019 Vitaliy Zakaznikov (TestFlows Test Framework http://testflows.com)
+# Copyright 2019 Katteli Inc.
+# TestFlows Test Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,24 +16,23 @@ import time
 
 from testflows._core.cli.colors import color
 from testflows._core.utils.timefuncs import localfromtimestamp
-from testflows._core.transform.log import message
+from testflows._core.message import Message
 
-def transform(stop):
+def transform(stop, divider="\n"):
     """Transform parsed log line into a nice format.
 
     :param stop: stop event
     """
     line = None
-    divider = ""
     version = None
     started = None
     while True:
-        if type(line) == message.RawVersion:
-            version = line.version
-            started = localfromtimestamp(line.p_time)
+        if line and line["message_keyword"] == Message.VERSION.name:
+            version = line["framework_version"]
+            started = localfromtimestamp(line["message_time"])
         if stop.is_set():
             if started is not None and version is not None:
-                line = color(f"{divider}\nExecuted on {started:%b %d,%Y %-H:%M}\nTestFlows Test Framework v{version}\n",
+                line = color(f"{divider}Executed on {started:%b %d,%Y %-H:%M}\nTestFlows Test Framework v{version}\n",
                     "white", attrs=["dim"])
             else:
                 line = None
